@@ -97,7 +97,7 @@ void Uic::createAttrDecl( const TQDomElement& e )
   \sa createObjectDecl()
  */
 
-static bool createdCentralWidget = FALSE;
+static bool createdCentralWidget = false;
 
 TQString Uic::createObjectImpl( const TQDomElement &e, const TQString& parentClass, const TQString& par, const TQString& layout )
 {
@@ -105,7 +105,7 @@ TQString Uic::createObjectImpl( const TQDomElement &e, const TQString& parentCla
     if ( parent == "this" && isMainWindow ) {
 	if ( !createdCentralWidget )
 	    out << indent << "setCentralWidget(TQt::Widget(this, \"qt_central_widget\"));" << endl;
-	createdCentralWidget = TRUE;
+	createdCentralWidget = true;
 	parent = "centralWidget()";
     }
     TQDomElement n;
@@ -172,7 +172,7 @@ TQString Uic::createObjectImpl( const TQDomElement &e, const TQString& parentCla
 
     lastItem = "undef";
     // set the properties and insert items
-    bool hadFrameShadow = FALSE;
+    bool hadFrameShadow = false;
     for ( n = e.firstChild().toElement(); !n.isNull(); n = n.nextSibling().toElement() ) {
 	if ( n.tagName() == "property" ) {
 	    bool stdset = stdsetdef;
@@ -187,7 +187,7 @@ TQString Uic::createObjectImpl( const TQDomElement &e, const TQString& parentCla
 	    if ( prop == "name" )
 		continue;
 	    if ( isLine && prop == "frameShadow" )
-		hadFrameShadow = TRUE;
+		hadFrameShadow = true;
 	    if ( prop == "buddy" && value.startsWith("\"") && value.endsWith("\"") ) {
 		buddies << Buddy( objName, value.mid(1, value.length() - 2 ) );
 		continue;
